@@ -1,9 +1,10 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2017,2018,2019,2020,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-# Copyright © 2023 Andrius Štikonas <andrius@stikonas.eu>
-# Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
+# Copyright © 2017,2018,2019,2020,2022,2023,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2023, 2024 Andrius Štikonas <andrius@stikonas.eu>
+# Copyright © 2023, 2024 Ekaitz Zarraga <ekaitz@elenq.tech>
+# Copyright © 2024 Michael Forney <mforney@mforney.org>
 #
 # This file is part of GNU Mes.
 #
@@ -217,6 +218,7 @@ lib/tests/scaffold/82-define.c
 lib/tests/scaffold/83-heterogenoous-init.c
 lib/tests/scaffold/84-struct-field-list.c
 lib/tests/scaffold/85-sizeof.c
+lib/tests/scaffold/86-comma-operator-types.c
 "
 
 gnu_tests="
@@ -268,10 +270,20 @@ lib/tests/scaffold/91-goto-array.c
 
     if test $mes_cpu = x86_64; then
         xfail_tests="$xfail_tests
+lib/tests/scaffold/16-cast.c
+lib/tests/scaffold/17-compare-unsigned-le.c
 lib/tests/scaffold/17-compare-rotated.c
 lib/tests/scaffold/a0-call-trunc-int.c
 "
     fi
+
+    if test $mes_cpu = arm; then
+        xfail_tests="$xfail_tests
+lib/tests/scaffold/17-compare-rotated.c
+lib/tests/scaffold/67-m1-overflow-check.c
+"
+    fi
+
     if test $mes_cpu = riscv64; then
         xfail_tests="$xfail_tests
 lib/tests/scaffold/17-compare-rotated.c
@@ -314,15 +326,15 @@ lib/tests/scaffold/70-extern.c
     fi
 fi
 
-# Allow for make check TESTS=lib/tests/setjmp/80-setjmp.c
-if test -n "$bootstrap"; then
-    TESTS="${TESTS-$mes_tests$tcc_tests}"
+# Allow for make check MESCC_TESTS=lib/tests/setjmp/80-setjmp.c
+if "$bootstrap" = "true"; then
+    TESTS="${MESCC_TESTS-$mes_tests$tcc_tests}"
 else
-    TESTS="${TESTS-$mes_tests$tcc_tests$gnu_tests}"
+    TESTS="${MESCC_TESTS-$mes_tests$tcc_tests$gnu_tests}"
 fi
 
-# Allow for make check xfail_tests=lib/tests/setjmp/80-setjmp.c
-XFAIL_TESTS="${XFAIL_TESTS-$xfail_tests}"
+# Allow for make check MESCC_XFAIL_TESTS=lib/tests/setjmp/80-setjmp.c
+XFAIL_TESTS="${MESCC_XFAIL_TESTS-$xfail_tests}"
 
 recheck=${recheck-false}
 test_ext=.c
