@@ -3,6 +3,7 @@
 # GNU Mes --- Maxwell Equations of Software
 # Copyright © 2019,2020,2021,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 # Copyright © 2023 Timothy Sample <samplet@ngyro.com>
+# Copyright © 2024 Andrius Štikonas <andrius@stikonas.eu>
 #
 # This file is part of GNU Mes.
 #
@@ -109,16 +110,8 @@ lib/mes/ntoab.c
 lib/mes/oputc.c
 lib/mes/ultoa.c
 lib/mes/utoa.c
-"
-
-# /include/mes/lib-cc.h already defines __raise.c as a macro for __TCC__
-# if we include it in the target source lib it explodes when reading the
-# function definition
-if test $compiler != tcc; then
-    libmes_SOURCES="$libmes_SOURCES
 lib/stub/__raise.c
 "
-fi
 
 if test $mes_libc = mes; then
     libmes_SOURCES="$libmes_SOURCES
@@ -335,6 +328,8 @@ lib/stub/sigaction.c
 lib/stub/ldexp.c
 lib/stub/mprotect.c
 lib/stub/localtime.c
+lib/stub/putenv.c
+lib/stub/realpath.c
 lib/stub/sigemptyset.c
 lib/$mes_cpu-mes-$compiler/setjmp.c
 "
@@ -356,6 +351,7 @@ lib/posix/alarm.c
 lib/posix/execl.c
 lib/posix/execlp.c
 lib/posix/mktemp.c
+lib/posix/pathconf.c
 lib/posix/sbrk.c
 lib/posix/sleep.c
 lib/posix/unsetenv.c
