@@ -1,8 +1,8 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2018,2019,2021,2022,2023 Janneke Nieuwenhuizen <janneke@gnu.org>
-# Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
+# Copyright © 2018,2019,2021,2022,2023,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2023, 2024 Ekaitz Zarraga <ekaitz@elenq.tech>
 #
 # This file is part of GNU Mes.
 #
@@ -21,7 +21,7 @@
 
 set -e
 
-VERSION=0.26
+VERSION=0.26.1
 srcdir=${srcdir-$(dirname $0)}
 srcdest=
 if test "$srcdir" != "."; then
@@ -170,7 +170,7 @@ subst () {
     $1 > $2
 }
 
-host=${host-$($CC -dumpmachine 2>/dev/null)}
+host=${host-$($CC -dumpmachine 2>/dev/null)} || true
 if test -z "$host$host_type"; then
     mes_cpu=${arch-$(get_machine || uname -m)}
 else
@@ -266,6 +266,7 @@ EOF
 
 mkdir -p include/arch
 cp -f -v ${srcdest}include/${mes_kernel}/${mes_cpu}/kernel-stat.h include/arch
+cp -f -v ${srcdest}include/${mes_kernel}/${mes_cpu}/signal.h include/arch
 cp -f -v ${srcdest}include/${mes_kernel}/${mes_cpu}/syscall.h include/arch
 
 cat <<EOF
