@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2016,2017,2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -26,5 +27,11 @@ dup2 (int old, int new)
 {
   long long_old = old;
   long long_new = new;
+#if defined (SYS_dup2)
   return _sys_call2 (SYS_dup2, long_old, long_new);
+#elif defined (SYS_dup3)
+  return _sys_call3 (SYS_dup3, long_old, long_new, 0);
+#else
+#error No usable dup2 syscall
+#endif
 }
