@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -20,10 +21,17 @@
 
 #include <linux/syscall.h>
 #include <arch/syscall.h>
+#include <fcntl.h>
 #include <sys/stat.h>
 
 ssize_t
 readlink (char const *file_name, char *buffer, size_t size)
 {
+#if defined (SYS_readlink)
   return _sys_call3 (SYS_readlink, (long) file_name, (long) buffer, (long) size);
+#elif defined (SYS_readlinkat)
+  return _sys_call4 (SYS_readlinkat, AT_FDCWD, (long) file_name, (long) buffer, (long) size);
+#else
+#error No usable readlink syscall
+#endif
 }
