@@ -18,8 +18,8 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
-#include <pwd.h>
+#include <mes/lib.h>
+#include <errno.h>
 
 int
 rand (void)
