@@ -1,5 +1,5 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2020,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2019 Danny Milosavljevic <dannym@scratchpost.org>
 ;;; Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
 ;;;
@@ -631,7 +631,9 @@
     (r0/r1 . ,armv4:r0/r1)
     (r0<<r1 . ,armv4:r0<<r1)
     (r0>>r1 . ,armv4:r0>>r1)
-    (r0>>r1-signed . ,armv4:r0>>r1-signed)
+    ;; This causes a segfault in 60-math-itoa
+    ;; (r0>>r1-signed . ,armv4:r0>>r1-signed)
+    (r0>>r1-signed . ,armv4:r0>>r1)
     (r1->r0 . ,armv4:r1->r0)
     (r2->r0 . ,armv4:r2->r0)
     (ret . ,armv4:ret)
