@@ -47,7 +47,7 @@
 
 (define (cons* . rest)
   (if (null? (cdr rest)) (car rest)
-      (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
+      (cons (car rest) (core:apply cons* (cdr rest) (current-environment)))))
 
 (define (memq x lst)
   (if (null? lst) #f
