@@ -23,10 +23,10 @@
 ;;;;;;;;;;;;;;;
   (define (cons* . rest)
     (if (null? (cdr rest)) (car rest)
-        (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
+        (cons (car rest) (core:apply cons* (cdr rest) (current-environment)))))
 
   (define (apply f h . t)
-    (if (null? t) (core:apply f h (current-module))
+    (if (null? t) (core:apply f h (current-environment))
         (apply f (apply cons* (cons h t)))))
 
   (define (append . rest)
